#include <iostream>
#include <iomanip>
#include <stdlib.h>
#include <stdio.h>
#include <string>
#include <vector>

#include "TStyle.h"
#include "TH1F.h"
#include "TLatex.h"
#include "TFrame.h"
#include "TCanvas.h"
#include "TGraphErrors.h"
#include "TMarker.h"
#include "TLine.h"
#include "TBox.h"

using namespace std;

// titles and axis, marker size, etc.
float markerSize = 1.0;
float titleOffsetX = 1.15;
float titleOffsetY = 1.1;
float titleSizeX = 0.05;
float titleSizeY = 0.05;
float labelSizeX = 0.05;
float labelOffsetX = 0.006;
float labelOffsetY = 0.004;
float labelSizeY = 0.045;
int ndivx = 506;
int ndivy = 506;
float aspR = 1.4; 

// texts
size_t ntxt = 1;
vector<string> txt(100);
vector<float>  txtSize(100);
vector<float>  txtX(100);
vector<float>  txtY(100);
vector<int>    txtNDC(100);
vector<int>    txtAlign(100);
vector<int>    txtFont(100);
vector<int>    txtColor(100);
void text_init();
void text_reset();
void text_write();

// drawings
void draw_bin_grid( float xmin, float xmax, float ymin, float ymax, 
		    int iCol=kGray+2, int iStyle=kDotted );
// constants
const float W_br_lnu    = 10.800e-02;
const float Z0_br_ll    =  3.366e-02;

int version = 0;

class DataPoint
{
public: 

  DataPoint( float sigma, float e_stat, float e_tot, 
	     float sigma_theo, float e_theo,
	     float xpos, float dx, int type) 
    : _sigma(sigma), _e_stat(e_stat), _e_tot(e_tot),
      _sigma_theo(sigma_theo), _e_theo(e_theo),
      _xpos(xpos), _dx(dx), _type(type)
  {
  }

  virtual ~DataPoint() 
  {
  }

  void draw()
  {
    if (_type==8) 
      {
	_theoColor = 209;
        _expFillColor = kRed;
      } else if (_type == 7)
      {
	_theoColor = kBlue;
        _expFillColor = kWhite;
      } else
      {
	_theoColor = kBlue;
        _expFillColor = kWhite;
      }
   
   
    if( _sigma>0 )
      {
    
	TGraphErrors _theoPoint(1);
	_theoPoint.SetMarkerSize(0);
	_theoPoint.SetLineColor(_theoColor);
	_theoPoint.SetLineWidth(2);
	_theoPoint.SetPoint(1, _xpos, _sigma_theo );
	_theoPoint.SetPointError( 1, _dx/2., 0 );
	_theoPoint.DrawClone("ez");

	
	TGraphErrors _dataTotPoint(1);
	_dataTotPoint.SetPoint(1, _xpos, _sigma );
	_dataTotPoint.SetPointError( 1, 0, _e_tot );
	_dataTotPoint.SetLineWidth(1);
	_dataTotPoint.SetLineColor(kRed);
	_dataTotPoint.SetMarkerSize(0);
	_dataTotPoint.DrawClone("e");	

 	TMarker _dataPoint( _xpos, _sigma, kFullCircle );
 	_dataPoint.SetMarkerSize(markerSize);
	_dataPoint.SetMarkerColor(_expFillColor);
	_dataPoint.DrawClone();
	_dataPoint.SetMarkerStyle(kOpenCircle);
 	_dataPoint.SetMarkerColor(kRed);
	_dataPoint.DrawClone();
	

      }
    else if( _sigma<0 )
      {

	TGraphErrors _theoPoint(1);
	_theoPoint.SetMarkerSize(0);
	_theoPoint.SetLineColor(kBlue);
	_theoPoint.SetLineWidth(2);
	_theoPoint.SetPoint(1, _xpos, _sigma_theo );
	_theoPoint.SetPointError( 1, _dx/2., 0 );
	_theoPoint.DrawClone("ez");

 	TBox _limit(_xpos-_dx/5.,-_sigma, _xpos+_dx/5., -1.5*_sigma);
 	_limit.SetFillStyle(3354);
 	_limit.SetFillColor( kRed );
	_limit.DrawClone();

 	TGraphErrors _dataTotPoint(1);
 	_dataTotPoint.SetPoint(1, _xpos, -_sigma );
 	_dataTotPoint.SetPointError( 1, _dx/4., 0 );
 	_dataTotPoint.SetLineWidth(2);
 	_dataTotPoint.SetLineColor(kRed);
 	_dataTotPoint.SetMarkerSize(0);	
	_dataTotPoint.DrawClone("ez");

      }
    else
      {
	float dy_ = 1/2.5;


 	TBox _limit(_xpos-_dx/3., _sigma_theo/(dy_*dy_*dy_), 
		    _xpos+_dx/3., 1.5*_sigma_theo/(dy_*dy_*dy_) );
 	_limit.SetFillStyle(3354);
 	_limit.SetFillColor( kRed );
	_limit.DrawClone();

 	TGraphErrors _limitLine(1);
 	_limitLine.SetPoint(1, _xpos, _sigma_theo/(dy_*dy_*dy_) );
 	_limitLine.SetPointError( 1, _dx/2., 0 );
 	_limitLine.SetLineWidth(2);
 	_limitLine.SetLineColor(kRed);
 	_limitLine.SetMarkerSize(0);	
	_limitLine.DrawClone("ez");


	TGraphErrors _dataTotPoint(1);
	_dataTotPoint.SetPoint(1, _xpos, _sigma_theo/(dy_*dy_) );
	_dataTotPoint.SetPointError( 1, 0, _e_tot/(dy_*dy_) );
	_dataTotPoint.SetLineWidth(1);
	_dataTotPoint.SetLineColor(kRed);
	_dataTotPoint.SetMarkerSize(0);
	_dataTotPoint.DrawClone("e");	

 	TMarker _dataPoint( _xpos, _sigma_theo/(dy_*dy_), kFullCircle );
 	_dataPoint.SetMarkerSize(markerSize);
	_dataPoint.SetMarkerColor(kWhite);
	_dataPoint.DrawClone();
	_dataPoint.SetMarkerStyle(kOpenCircle);
 	_dataPoint.SetMarkerColor(kRed);
	_dataPoint.DrawClone();
	

	TGraphErrors _dataTotPoint8(1);
	_dataTotPoint8.SetPoint(1, _xpos, _sigma_theo/dy_ );
	_dataTotPoint8.SetPointError( 1, 0, _e_tot/dy_ );
	_dataTotPoint8.SetLineWidth(1);
	_dataTotPoint8.SetLineColor(kRed);
	_dataTotPoint8.SetMarkerSize(0);
	_dataTotPoint8.DrawClone("e");	

 	TMarker _dataPoint8( _xpos, _sigma_theo/dy_, kFullCircle );
 	_dataPoint8.SetMarkerSize(markerSize);
	_dataPoint8.SetMarkerColor(kRed);
	_dataPoint8.DrawClone();
	_dataPoint8.SetMarkerStyle(kOpenCircle);
 	_dataPoint8.SetMarkerColor(kRed);
	_dataPoint8.DrawClone();


	TGraphErrors _theoPoint(1);
	_theoPoint.SetMarkerSize(0);
	_theoPoint.SetLineColor(kBlue);
	_theoPoint.SetLineWidth(2);
	_theoPoint.SetPoint(1, _xpos, _sigma_theo );
	_theoPoint.SetPointError( 1, _dx/2., 0 );
	_theoPoint.DrawClone("ez");

	TGraphErrors _theoPoint8(1);
	_theoPoint8.SetMarkerSize(0);
	_theoPoint8.SetLineColor(209);
	_theoPoint8.SetLineWidth(2);
	_theoPoint8.SetPoint(1, _xpos, _sigma_theo*dy_ );
	_theoPoint8.SetPointError( 1, _dx/2., 0 );
	_theoPoint8.DrawClone("ez");



	txt[ntxt] = "CMS 95%CL limit";
	txtSize[ntxt] = 0.03;
	txtX[ntxt] = _xpos + 0.75*_dx;
	txtY[ntxt] = _sigma_theo/(dy_*dy_*dy_);
	txtAlign[ntxt] = 12;
	txtFont[ntxt] = 42;
	ntxt++;


	txt[ntxt] = "7 TeV CMS measurement (stat#oplussyst) ";
	txtSize[ntxt] = 0.03;
	txtX[ntxt] = _xpos + 0.75*_dx;
	txtY[ntxt] = _sigma_theo/(dy_*dy_);
	txtAlign[ntxt] = 12;
	txtFont[ntxt] = 42;
	ntxt++;


	txt[ntxt] = "8 TeV CMS measurement (stat#oplussyst) ";
	txtSize[ntxt] = 0.03;
	txtX[ntxt] = _xpos + 0.75*_dx;
	txtY[ntxt] = _sigma_theo/dy_;
	txtAlign[ntxt] = 12;
	txtFont[ntxt] = 42;
	ntxt++;


	txt[ntxt] = "7 TeV Theory prediction";
	txtSize[ntxt] = 0.03;
	txtX[ntxt] = _xpos + 0.75*_dx;
	txtY[ntxt] = _sigma_theo;
	txtAlign[ntxt] = 12;
	txtFont[ntxt] = 42;
	ntxt++;

	txt[ntxt] = "8 TeV Theory prediction";
	txtSize[ntxt] = 0.03;
	txtX[ntxt] = _xpos + 0.75*_dx;
	txtY[ntxt] = _sigma_theo*dy_;
	txtAlign[ntxt] = 12;
	txtFont[ntxt] = 42;
	ntxt++;


      }
  }

private:
  float _sigma;
  float _e_stat;
  float _e_tot;
  float _sigma_theo;
  float _e_theo;
  float _xpos;
  float _dx;
  int _theoColor;
  int _expFillColor;
  int _type;
};

TCanvas*
Sigma(float ymin=0.05, float ymax=900000 )
{
  text_init();

  gStyle->SetEndErrorSize(5);
  gStyle->SetHatchesLineWidth(1);
  gStyle->SetHatchesSpacing(0.8);

  vector<string> cutName;
    
  enum { k_W=0, k_Wp, k_Wm, k_W8, k_W1jet, k_W2jet, k_W3jet, k_W4jet, k_Z, k_Z8, k_Z1jet, k_Z2jet, k_Z3jet, k_Z4jet, k_Wg, k_Zg, k_WW, k_WW8, k_WZ, k_ZZ, k_ZZ8, k_H127, k_nChan };

  vector<string> chanName( k_nChan );
  vector<float> 
    chanSigma( k_nChan,0 ), 
    chanEStat( k_nChan,0 ),
    chanESyst( k_nChan,0 ),
    chanETot(  k_nChan,0 ),
    chanTheo(  k_nChan,0 ),
    chanETheo( k_nChan,0 );

  chanName[k_W]  = "W";
  chanName[k_W8]  = "W8";
  chanName[k_Wp] = "W^{ +}";
  chanName[k_Wm] = "W^{ -}";
  chanName[k_W1jet] = "#geq1j";
  chanName[k_W2jet] = "#geq2j";
  chanName[k_W3jet] = "#geq3j";
  chanName[k_W4jet] = "#geq4j";

  chanName[k_Z]  = "Z";
  chanName[k_Z8]  = "Z8";
  chanName[k_Z1jet] = "#geq1j";
  chanName[k_Z2jet] = "#geq2j";
  chanName[k_Z3jet] = "#geq3j";
  chanName[k_Z4jet] = "#geq4j";

  chanName[k_Wg] = "W#gamma";

  chanName[k_Zg] = "Z#gamma";

  chanName[k_WW] = "WW";
  chanName[k_WW8]= "WW8";
  chanName[k_WZ] = "WZ";
  chanName[k_ZZ] = "ZZ";
  chanName[k_ZZ8] = "ZZ8";

  chanName[k_H127] = "#splitline{H#scale[0.85]{(125)}}{#rightarrow ZZ}";

  int chanColor = kBlue;
  int type = 7;

  float scale_;
  
  scale_ = (1000./W_br_lnu);
  chanSigma[k_W]  = 10.30 * scale_; 
  chanEStat[k_W]  =  0.02 * scale_;
  chanESyst[k_W]  =  0.10 * scale_;
  chanETot[k_W]   =  sqrt( 
			  chanEStat[k_W]*chanEStat[k_W]
			  +
			  chanESyst[k_W]*chanESyst[k_W]
			  + 
			  0.10*0.10 // theory
			   );
  chanTheo[k_W] = 10.44 * scale_;
  chanETheo[k_W] = 0.27 * scale_;


  chanSigma[k_Wp]  =  6.04 * scale_; 
  chanEStat[k_Wp]  =  0.02 * scale_;
  chanESyst[k_Wp]  =  0.06 * scale_;
  chanETot[k_Wp]   =  sqrt( 
			   chanEStat[k_Wp]*chanEStat[k_Wp]
			   +
			   chanESyst[k_Wp]*chanESyst[k_Wp]
			   + 
			   0.08*0.08 // theory
			    );
  chanTheo[k_Wp] =  6.15 * scale_;
  chanETheo[k_Wp] = 0.17 * scale_;

  chanSigma[k_Wm]  =  4.26 * scale_; 
  chanEStat[k_Wm]  =  0.01 * scale_;
  chanESyst[k_Wm]  =  0.04 * scale_;
  chanETot[k_Wm]   =  sqrt( 
			   chanEStat[k_Wm]*chanEStat[k_Wm]
			   +
			   chanESyst[k_Wm]*chanESyst[k_Wm]
			   + 
			   0.07*0.07 // theory
			    );
  chanTheo[k_Wm] =  4.29 * scale_;
  chanETheo[k_Wm] = 0.11 * scale_;


  chanSigma[k_W8]  = 11.82 * scale_; 
  chanEStat[k_W8]  =  0.04 * scale_;
  chanESyst[k_W8]  =  0.62 * scale_;
  chanETot[k_W8]   =  sqrt( 
			  chanEStat[k_W8]*chanEStat[k_W8]
			  +
			  chanESyst[k_W8]*chanESyst[k_W8]
			   );
  chanTheo[k_W8] = 12.503 * scale_;
  chanETheo[k_W8] = 0.018 * scale_;



  scale_ = (1000./Z0_br_ll);
  chanSigma[k_Z]  =  0.974 * scale_; 
  chanEStat[k_Z]  =  0.007 * scale_;
  chanESyst[k_Z]  =  0.007 * scale_;
  chanETot[k_Z]   =  sqrt( 
			  chanEStat[k_Z]*chanEStat[k_Z]
			  +
			  chanESyst[k_Z]*chanESyst[k_Z]
			  + 
			  0.018*0.018 // theory
			   );

  chanTheo[k_Z] =  0.97 * scale_;
  chanETheo[k_Z] = 0.03 * scale_;

  chanSigma[k_Z8]  =  1.08 * scale_; 
  chanEStat[k_Z8]  =  0.01 * scale_;
  chanESyst[k_Z8]  =  0.05 * scale_;
  chanETot[k_Z8]   =  sqrt( 
			  chanEStat[k_Z8]*chanEStat[k_Z8]
			  +
			  chanESyst[k_Z8]*chanESyst[k_Z8]
			   );
  chanTheo[k_Z8] =  1.1323 * scale_;
  chanETheo[k_Z8] = 0.0009 * scale_;
 



  scale_ = chanSigma[k_W];

  chanSigma[k_W1jet]  = 0.136 * scale_;
  chanEStat[k_W1jet]  =   0.002 * scale_;
  chanETot[k_W1jet]   =  sqrt( 0.007*0.007 + 0.02*0.02 + 0.001*0.001 ) * scale_;
  chanESyst[k_W1jet]  =  sqrt( chanETot[k_W1jet]*chanETot[k_W1jet] 
			       - 
			       chanEStat[k_W1jet]*chanEStat[k_W1jet]
			       );
  chanTheo[k_W1jet]  = 1.23959384858608246e-01 * scale_;
  chanETheo[k_W1jet] = 0. * scale_;

  chanSigma[k_W2jet]  = 0.026 * scale_;
  chanEStat[k_W2jet]  =   0.001 * scale_;
  chanETot[k_W2jet]   =  sqrt( 0.002*0.002 + 0.004*0.004 + 0.002*0.002 ) * scale_;
  chanESyst[k_W2jet]  =  sqrt( chanETot[k_W2jet]*chanETot[k_W2jet] 
			       - 
			       chanEStat[k_W2jet]*chanEStat[k_W2jet]
			       );
  chanTheo[k_W2jet]  = 2.30696983635425568e-02 * scale_;
  chanETheo[k_W2jet] = 0. * scale_;

  chanSigma[k_W3jet]  = 0.0041 * scale_;
  chanEStat[k_W3jet]  =   0.0003 * scale_;
  chanETot[k_W3jet]   =  sqrt( 0.0005*0.0005 + 0.0008*0.0008 + 0.0003*0.0003 ) * scale_;
  chanESyst[k_W3jet]  =  sqrt( chanETot[k_W3jet]*chanETot[k_W3jet] 
			       - 
			       chanEStat[k_W3jet]*chanEStat[k_W3jet]
			       );
  chanTheo[k_W3jet]  = 3.99857712909579277e-03 * scale_;
  chanETheo[k_W3jet] = 0. * scale_;

  chanSigma[k_W4jet]  = 0.00059 * scale_;
  chanEStat[k_W4jet]  =   0.00011 * scale_;
  chanETot[k_W4jet]   =  sqrt( 0.00017*0.00017 + 0.00012*0.00012 + 0.00015*0.00015 ) * scale_;
  chanESyst[k_W4jet]  =  sqrt( chanETot[k_W4jet]*chanETot[k_W4jet] 
			       - 
			       chanEStat[k_W4jet]*chanEStat[k_W4jet]
			       );
  chanTheo[k_W4jet]  = 7.47408485040068626e-04 * scale_;
  chanETheo[k_W4jet] = 0. * scale_;

  scale_ = chanSigma[k_Z];

  chanSigma[k_Z1jet]  = 0.149 * scale_;
  chanEStat[k_Z1jet]  =   0.005 * scale_;
  chanETot[k_Z1jet]   =  sqrt( 0.011*0.011 + 0.022*0.022 + 0.001*0.001 ) * scale_;
  chanESyst[k_Z1jet]  =  sqrt( chanETot[k_Z1jet]*chanETot[k_Z1jet] 
			       - 
			       chanEStat[k_Z1jet]*chanEStat[k_Z1jet]
			       );
  chanTheo[k_Z1jet]  = 1.49421244859695435e-01 * scale_;
  chanETheo[k_Z1jet] = 0. * scale_;

  chanSigma[k_Z2jet]  = 0.028 * scale_;
  chanEStat[k_Z2jet]  =   0.003 * scale_;
  chanETot[k_Z2jet]   =  sqrt( 0.004*0.004 + 0.004*0.004 + 0.001*0.001 ) * scale_;
  chanESyst[k_Z2jet]  =  sqrt( chanETot[k_Z2jet]*chanETot[k_Z2jet] 
			       - 
			       chanEStat[k_Z2jet]*chanEStat[k_Z2jet]
			       );
  chanTheo[k_Z2jet]  = 2.87458151578903198e-02 * scale_;
  chanETheo[k_Z2jet] = 0. * scale_;

  chanSigma[k_Z3jet]  = 0.0042 * scale_;
  chanEStat[k_Z3jet]  =   0.0011 * scale_;
  chanETot[k_Z3jet]   =  sqrt( 0.0012*0.0012 + 0.0008*0.0008 + 0.0003*0.0003 ) * scale_;
  chanESyst[k_Z3jet]  =  sqrt( chanETot[k_Z3jet]*chanETot[k_Z3jet] 
			       - 
			       chanEStat[k_Z3jet]*chanEStat[k_Z3jet]
			       );
  chanTheo[k_Z3jet]  = 5.09246997535228729e-03 * scale_;
  chanETheo[k_Z3jet] = 0. * scale_;

  chanSigma[k_Z4jet]  = 0.00087 * scale_;
  chanEStat[k_Z4jet]  =   0.00050 * scale_;
  chanETot[k_Z4jet]   =  sqrt( 0.00056*0.00056 + 0.00017*0.00017 + 0.00010*0.00010 ) * scale_;
  chanESyst[k_Z4jet]  =  sqrt( chanETot[k_Z4jet]*chanETot[k_Z4jet] 
			       - 
			       chanEStat[k_Z4jet]*chanEStat[k_Z4jet]
			       );
  chanTheo[k_Z4jet]  = 9.34239011257886887e-04 * scale_;
  chanETheo[k_Z4jet] = 0. * scale_;

  scale_ = (1./W_br_lnu);

  chanSigma[k_Wg]  =  56.3 * scale_; 
  chanEStat[k_Wg]  =  5.0 * scale_;
  chanESyst[k_Wg]  =  5.0 * scale_;
  chanETot[k_Wg]   =  sqrt( 
			   chanEStat[k_Wg]*chanEStat[k_Wg]
			   +
			   chanESyst[k_Wg]*chanESyst[k_Wg]
			    );
  chanTheo[k_Wg] =  49.4 * scale_;
  chanETheo[k_Wg] =  3.8 * scale_;

  scale_ = (1./Z0_br_ll);

  chanSigma[k_Zg]  =  9.4 * scale_; 
  chanEStat[k_Zg]  =  1.0 * scale_;
  chanESyst[k_Zg]  =  0.6 * scale_;
  chanETot[k_Zg]   =  sqrt( 
			   chanEStat[k_Zg]*chanEStat[k_Zg]
			   +
			   chanESyst[k_Zg]*chanESyst[k_Zg]
			    );
  chanTheo[k_Zg] =  9.6 * scale_;
  chanETheo[k_Zg] = 0.4 * scale_;

  scale_ = 1.;

  chanSigma[k_WW]  =  52.4 * scale_; 
  chanEStat[k_WW]  =   2.0 * scale_;
  chanESyst[k_WW]  =   4.7 * scale_;
  chanETot[k_WW]   =  sqrt( 
			   chanEStat[k_WW]*chanEStat[k_WW]
			   +
			   chanESyst[k_WW]*chanESyst[k_WW]
			    );
  chanTheo[k_WW] =  47.0 * scale_;
  chanETheo[k_WW] =  2.0 * scale_;

  chanSigma[k_WW8]  =  68.4 * scale_; 
  chanEStat[k_WW8]  =   2.79 * scale_;
  chanESyst[k_WW8]  =   7.28 * scale_;
  chanETot[k_WW8]   =  sqrt( 
			   chanEStat[k_WW8]*chanEStat[k_WW8]
			   +
			   chanESyst[k_WW8]*chanESyst[k_WW8]
			    );
  chanTheo[k_WW8] =  57.25 * scale_;
  chanETheo[k_WW8] =  2.0 * scale_;



  chanSigma[k_WZ]  =  17.0 * scale_; 
  chanEStat[k_WZ]  =   2.4 * scale_;
  chanESyst[k_WZ]  =   1.1 * scale_;
  chanETot[k_WZ]   =  sqrt( 
			   chanEStat[k_WZ]*chanEStat[k_WZ]
			   +
			   chanESyst[k_WZ]*chanESyst[k_WZ]
			    );
  chanTheo[k_WZ] =  17.5 * scale_;
  chanETheo[k_WZ] =  0.088 * scale_;

  chanSigma[k_ZZ]  =   6.35 * scale_; 
  chanEStat[k_ZZ]  =   0.85 * scale_;
  chanESyst[k_ZZ]  =   0.40 * scale_;
  chanETot[k_ZZ]   =  sqrt( 
			   chanEStat[k_ZZ]*chanEStat[k_ZZ]
			   +
			   chanESyst[k_ZZ]*chanESyst[k_ZZ]
			    );
  chanTheo[k_ZZ] =   6.4 * scale_;
  chanETheo[k_ZZ] =  0.6 * scale_;


  chanSigma[k_ZZ8]  =   7.3 * scale_; 
  chanEStat[k_ZZ8]  =   1.2 * scale_;
  chanESyst[k_ZZ8]  =   0.4 * scale_;
  chanETot[k_ZZ8]   =  sqrt( 
			   chanEStat[k_ZZ8]*chanEStat[k_ZZ8]
			   +
			   chanESyst[k_ZZ8]*chanESyst[k_ZZ8]
			    );
  chanTheo[k_ZZ8] =   7.8 * scale_;
  chanETheo[k_ZZ8] =  0.6 * scale_;



  scale_ = 1.;

  float ZZsigBR_ = (15.31+1.205) * 0.0317;
  chanSigma[k_H127]  =   -2.5 * ZZsigBR_; // limite
  chanEStat[k_H127]  =   0;
  chanESyst[k_H127]  =   0;
  chanETot [k_H127]  =   0;
  chanTheo [k_H127]  =   ZZsigBR_;
  chanETheo[k_H127]  =   ZZsigBR_ * 0.20;

  bool verbose_(false);
  if( verbose_ )
    {
      for( size_t ii=0; ii<k_nChan; ii++ )
	{
	  cout << chanName[ii] 
	       << " " << chanSigma[ii]
	       << " +/- " << chanEStat[ii] << "(stat)"
	       << " +/- " << chanESyst[ii] << "(syst)"
	       << " TH="  << chanTheo[ii] 
	       << " +/- " << chanETheo[ii] 
	       << endl;
	}
    }
  
  float shift_ = 2.;
  float size_  = 0.06;

  vector<int> channel_;
  vector<float> xpos_;
  vector<float> dx_;
  vector<float> vline_;
  vector<float> vmin_;
  vector<float> vmax_;
  vector<int>   vstyle_;

  size_t nBin_ = 1;

  vline_.push_back( nBin_ );
  vmin_.push_back( 1. );
  vmax_.push_back( 1. );
  vstyle_.push_back(2);

  size_t DX_;

  if( version==0 )
    {

      channel_.push_back(k_W);
      DX_=2;
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);

      txt[ntxt] = chanName[k_W];
      txtSize[ntxt] = size_;
      txtX[ntxt] = nBin_+DX_;
      txtY[ntxt] = chanTheo[k_W] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      ntxt++;

      nBin_+=DX_;
      channel_.push_back(k_W8);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);

      nBin_-=DX_;

      DX_=1;
      
      channel_.push_back(k_W1jet);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      txt[ntxt] = chanName[k_W1jet];
      txtSize[ntxt] = 0.55 * size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_W1jet] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      nBin_ += DX_;

      channel_.push_back(k_W2jet);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      txt[ntxt] = chanName[k_W2jet];
      txtSize[ntxt] = 0.55 * size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_W2jet] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      nBin_ += DX_;

      channel_.push_back(k_W3jet);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      txt[ntxt] = chanName[k_W3jet];
      txtSize[ntxt] = 0.55 * size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_W3jet] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      //nBin_ += DX_;

//       channel_.push_back(k_Wp);
//       xpos_.push_back(nBin_+0.5*DX_);
//       dx_.push_back(DX_);
//       txt[ntxt] = chanName[k_Wp];
//       txtSize[ntxt] = 0.55 * size_;
//       txtX[ntxt] = nBin_+0.5*DX_;
//       txtY[ntxt] = chanTheo[k_Wp] / (shift_*1.5);
//       txtAlign[ntxt] = 21;
//       txtFont[ntxt] = 42;
//       ntxt++;
      nBin_ += DX_;

      channel_.push_back(k_W4jet);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      txt[ntxt] = chanName[k_W4jet];
      txtSize[ntxt] = 0.55 * size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_W4jet] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      //      nBin_ += DX_;

//       channel_.push_back(k_Wm);
//       xpos_.push_back(nBin_+0.5*DX_);
//       dx_.push_back(DX_);
//       txt[ntxt] = chanName[k_Wm];
//       txtSize[ntxt] = 0.55*size_;
//       txtX[ntxt] = nBin_+0.5*DX_;
//       txtY[ntxt] = chanTheo[k_Wm] / (shift_*1.5);
//       txtAlign[ntxt] = 21;
//       txtFont[ntxt] = 42;
//       ntxt++;
      nBin_ += DX_;

      vline_.push_back( nBin_ );
      vmin_.push_back( 200. );
      vmax_.push_back( 1. );
      vstyle_.push_back(3);

      DX_=2;

      channel_.push_back(k_Z);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);


      txt[ntxt] = chanName[k_Z];
      txtSize[ntxt] = size_;
      txtX[ntxt] = nBin_+DX_;
      txtY[ntxt] = chanTheo[k_Z] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      ntxt++;

      nBin_+=DX_;
      channel_.push_back(k_Z8);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      nBin_-=DX_;


      DX_=1;

      channel_.push_back(k_Z1jet);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      txt[ntxt] = chanName[k_Z1jet];
      txtSize[ntxt] = 0.55 * size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_Z1jet] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      nBin_ += DX_;

      channel_.push_back(k_Z2jet);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      txt[ntxt] = chanName[k_Z2jet];
      txtSize[ntxt] = 0.55 * size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_Z2jet] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      nBin_ += DX_;

      channel_.push_back(k_Z3jet);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      txt[ntxt] = chanName[k_Z3jet];
      txtSize[ntxt] = 0.55 * size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_Z3jet] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      nBin_ += DX_;

      channel_.push_back(k_Z4jet);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);
      txt[ntxt] = chanName[k_Z4jet];
      txtSize[ntxt] = 0.55 * size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_Z4jet] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      nBin_ += DX_;

      vline_.push_back( nBin_ );
      vmin_.push_back( 1. );
      vmax_.push_back( 1. );
      vstyle_.push_back(2);


//       txt[ntxt] = "7, 8 TeV";
//       txtSize[ntxt] = 0.03;
//       txtX[ntxt] = 3.5;
//       txtY[ntxt] = chanTheo[k_W]/ shift_;
//       txtAlign[ntxt] = 21;
//       txtFont[ntxt] = 42;
//       txtColor[ntxt] = kGray+3;
//       ntxt++;

//       txt[ntxt] = "7, 8 TeV";
//       txtSize[ntxt] = 0.03;
//       txtX[ntxt] = 7.5;
//       txtY[ntxt] = chanTheo[k_Z]/ shift_;
//       txtAlign[ntxt] = 21;
//       txtFont[ntxt] = 42;
//       txtColor[ntxt] = kGray+3;
//       ntxt++;


      txt[ntxt] = "E_{T}^{ jet} > 30 GeV";
      txtSize[ntxt] = 0.03;
      txtX[ntxt] = 5;
      txtY[ntxt] = 50 * ymin;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;
      
      txt[ntxt] = "| #eta^{ jet} | < 2.4";
      txtSize[ntxt] = 0.03;
      txtX[ntxt] = 5;
      txtY[ntxt] = 20 * ymin;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;


    }
  else if( version==1 )
    {
      DX_=2;
      size_  = 0.04;
      shift_ = 3;

      channel_.push_back(k_Wp);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);

      txt[ntxt] = chanName[k_Wp];
      txtSize[ntxt] = size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_Wp] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      ntxt++;
      nBin_ += DX_;

      vline_.push_back( nBin_ );
      vmin_.push_back( 10. );
      vmax_.push_back( 1. );
      vstyle_.push_back(3);

      channel_.push_back(k_Wm);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);

      txt[ntxt] = chanName[k_Wm];
      txtSize[ntxt] = size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_Wm] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      ntxt++;
      nBin_ += DX_;

      vline_.push_back( nBin_ );
      vmin_.push_back( 10. );
      vmax_.push_back( 1. );
      vstyle_.push_back(3);

      channel_.push_back(k_Z);
      xpos_.push_back(nBin_+0.5*DX_);
      dx_.push_back(DX_);

      txt[ntxt] = chanName[k_Z];
      txtSize[ntxt] = size_;
      txtX[ntxt] = nBin_+0.5*DX_;
      txtY[ntxt] = chanTheo[k_Z] * shift_;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      ntxt++;
      nBin_ += DX_;

      vline_.push_back( nBin_ );
      vmin_.push_back( 1. );
      vmax_.push_back( 1. );
      vstyle_.push_back(2);

    }

  shift_ = 3;
  size_  = 0.04;

  DX_=2;

  channel_.push_back(k_Wg);
  xpos_.push_back(nBin_+0.5*DX_);
  dx_.push_back(DX_);

  txt[ntxt] = chanName[k_Wg];
  txtSize[ntxt] = size_;
  txtX[ntxt] = nBin_+0.5*DX_;
  txtY[ntxt] = chanTheo[k_Wg] * shift_;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  nBin_ += DX_;

  vline_.push_back( nBin_ );
  vmin_.push_back( 200. );
  vmax_.push_back( 10. );
  vstyle_.push_back(3);

  txt[ntxt] = "E_{T}^{ #gamma} > 10 GeV";
  txtSize[ntxt] = 0.03;
  txtX[ntxt] = nBin_;
  txtY[ntxt] = 50 * ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  txtColor[ntxt] = kGray+3;
  ntxt++;
      
  txt[ntxt] = "#DeltaR(#gamma,l) > 0.7";
  txtSize[ntxt] = 0.03;
  txtX[ntxt] = nBin_;
  txtY[ntxt] = 20 * ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  txtColor[ntxt] = kGray+3;
  ntxt++;

  channel_.push_back(k_Zg);
  xpos_.push_back(nBin_+0.5*DX_);
  dx_.push_back(DX_);

  txt[ntxt] = chanName[k_Zg];
  txtSize[ntxt] = size_;
  txtX[ntxt] = nBin_+0.5*DX_;
  txtY[ntxt] = chanTheo[k_Zg] * shift_;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  nBin_ += DX_;

  DX_ = 1;

  vline_.push_back( nBin_ );
  vmin_.push_back( 1. );
  vmax_.push_back( 200. );
  vstyle_.push_back(2);

  channel_.push_back(k_WW);
  xpos_.push_back(nBin_+0.5*DX_);
  dx_.push_back(DX_);

 
  nBin_ += DX_;



 channel_.push_back(k_WW8);
  xpos_.push_back(nBin_+0.5*DX_);
  dx_.push_back(DX_);


  txt[ntxt] = chanName[k_WW];
  txtSize[ntxt] = size_;
  txtX[ntxt] = nBin_+0.0*DX_;
  txtY[ntxt] = chanTheo[k_WW] * shift_;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

//   txt[ntxt] = "7, 8";
//   txtSize[ntxt] = 0.03;
//   txtX[ntxt] = nBin_;
//   txtY[ntxt] = chanTheo[k_WW] / (shift_*0.6);
//   txtAlign[ntxt] = 21;
//   txtFont[ntxt] = 42;
//   txtColor[ntxt] = kGray+3;
//   ntxt++;

//   txt[ntxt] = "TeV";
//   txtSize[ntxt] = 0.03;
//   txtX[ntxt] = nBin_;
//   txtY[ntxt] = chanTheo[k_WW] / (shift_);
//   txtAlign[ntxt] = 21;
//   txtFont[ntxt] = 42;
//   txtColor[ntxt] = kGray+3;
//   ntxt++;



  nBin_ += DX_;

  DX_ = 2;

  vline_.push_back( nBin_ );
  vmin_.push_back( 10. );
  vmax_.push_back( 500. );
  vstyle_.push_back(3);

  channel_.push_back(k_WZ);
  xpos_.push_back(nBin_+0.5*DX_);
  dx_.push_back(DX_);

  txt[ntxt] = chanName[k_WZ];
  txtSize[ntxt] = size_;
  txtX[ntxt] = nBin_+0.5*DX_;
  txtY[ntxt] = chanTheo[k_WZ] * shift_;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  nBin_ += DX_;

  DX_ = 1;

  vline_.push_back( nBin_ );
  vmin_.push_back( 10. );
  vmax_.push_back( 500. );
  vstyle_.push_back(3);

  channel_.push_back(k_ZZ);
  xpos_.push_back(nBin_+0.5*DX_);
  dx_.push_back(DX_);

  txt[ntxt] = chanName[k_ZZ];
  txtSize[ntxt] = size_;
  txtX[ntxt] = nBin_+ DX_;
  txtY[ntxt] = chanTheo[k_ZZ] * shift_;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  nBin_ += DX_;

  channel_.push_back(k_ZZ8);
  xpos_.push_back(nBin_+0.5*DX_);
  dx_.push_back(DX_);




//   vline_.push_back( nBin_ );
//   vmin_.push_back( 10. );
//   vmax_.push_back( 500. );
//   vstyle_.push_back(3);

//   channel_.push_back(k_ZZ);
//   xpos_.push_back(nBin_+0.5*DX_);
//   dx_.push_back(DX_);

//   txt[ntxt] = chanName[k_ZZ];
//   txtSize[ntxt] = size_;
//   txtX[ntxt] = nBin_+0.5*DX_;
//   txtY[ntxt] = chanTheo[k_ZZ] * shift_;
//   txtAlign[ntxt] = 21;
//   txtFont[ntxt] = 42;
//   ntxt++;

  nBin_ += DX_;



  vline_.push_back( nBin_ );
  vmin_.push_back( 1. );
  vmax_.push_back( 500. );
  vstyle_.push_back(2);

  DX_ = 2;

  channel_.push_back(k_H127);
  xpos_.push_back(nBin_+0.5*DX_);
  dx_.push_back(DX_);

  txt[ntxt] = chanName[k_H127];
  txtSize[ntxt] = 0.9 * size_;
  txtX[ntxt] = nBin_+0.5*DX_;
  txtY[ntxt] = chanTheo[k_H127] * 4 * shift_;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  nBin_ += DX_;

  vline_.push_back( nBin_ );
  vmin_.push_back( 1. );
  vmax_.push_back( 500. );
  vstyle_.push_back(2);

  nBin_++;

  txt[ntxt] = "36, 19 pb^{-1}";
  txtSize[ntxt] = 0.03;
  if( version==0 )
    txtX[ntxt] = 5;
  else if( version==1 )
    txtX[ntxt] = 4;
  txtY[ntxt] = 2 * ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  txt[ntxt] = "36 pb^{-1}";
  txtSize[ntxt] = 0.03;
  if( version==0 )
    txtX[ntxt] = 11;
  else if( version==1 )
    txtX[ntxt] = 9;
  txtY[ntxt] = 2 * ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  txt[ntxt] = "1.1 fb^{-1}";
  txtSize[ntxt] = 0.03;
  if( version==0 )
    txtX[ntxt] = 16.15;
  else if( version==1 )
    txtX[ntxt] = 27.5;
  txtY[ntxt] = 2 * ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  if (version==0) {

  txt[ntxt] = "4.9 fb^{-1}";
  txtSize[ntxt] = 0.03;
  txtX[ntxt] = 14.15;
  txtY[ntxt] = 3 * ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  txt[ntxt] = "3.5 fb^{-1}";
  txtSize[ntxt] = 0.03;
  txtX[ntxt] = 14.15;
  txtY[ntxt] = 1.5*ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  txt[ntxt] = "4.9 fb^{-1}";
  txtSize[ntxt] = 0.03;
  txtX[ntxt] = 18.15;
  txtY[ntxt] = 3 * ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  txt[ntxt] = "3.0 fb^{-1}";
  txtSize[ntxt] = 0.03;
  txtX[ntxt] = 18.15;
  txtY[ntxt] = 1.5*ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;


  }

  txt[ntxt] = "4.7 fb^{-1}";
  txtSize[ntxt] = 0.03;
  if( version==0 )
    txtX[ntxt] = 20.15;
  else if( version==1 )
    txtX[ntxt] = 18.15;
  txtY[ntxt] = 2 * ymin;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  txt[ntxt] = "JHEP10(2011)132";
  txtSize[ntxt] = 0.02;
  if( version==0 )
    txtX[ntxt] = 5;
  else if( version==1 )
    txtX[ntxt] = 4;
  if( version==0 )
    txtY[ntxt] = ymin/1.75;
  else if( version==1 )
    txtY[ntxt] = ymin/2;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;
  
  if( version==0 )
    {
      txt[ntxt] = "JHEP01(2012)010";
      txtSize[ntxt] = 0.02;
      txtX[ntxt] = 5;
      txtY[ntxt] = ymin/3.;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;

      txt[ntxt] = "CMS-PAS-SMP-12-011 (W/Z 8 TeV)";
      txtSize[ntxt] = 0.02;
      txtX[ntxt] = 5;
      txtY[ntxt] = ymin/5.;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;


    }

  txt[ntxt] = "PLB701(2011)535";
  txtSize[ntxt] = 0.02;
  if( version==0 )
    txtX[ntxt] = 11;
  else if( version==1 )
    txtX[ntxt] = 9;
  txtY[ntxt] = ymin/2;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

  txt[ntxt] = "CMS-PAS-EWK-11-010 (WZ)";
  txtSize[ntxt] = 0.02;
  if( version==0 )
    txtX[ntxt] = 15.85;
  else if( version==1 )
    txtX[ntxt] = 14;
  txtY[ntxt] = ymin/1.75;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

 if( version==0 )
    {
      txt[ntxt] = "CMS-PAS-SMP-12-005, ";
      txtSize[ntxt] = 0.02;
      txtX[ntxt] = 15.85;
      txtY[ntxt] = ymin/3.;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;

      txt[ntxt] = "007, 013, 014 (WW ZZ)  ";
      txtSize[ntxt] = 0.02;
      txtX[ntxt] = 15.85;
      txtY[ntxt] = ymin/5.;
      txtAlign[ntxt] = 21;
      txtFont[ntxt] = 42;
      txtColor[ntxt] = kGray+3;
      ntxt++;


    }


  txt[ntxt] = "hep-ex:1202.1997";
  txtSize[ntxt] = 0.02;
  if( version==0 )
    txtX[ntxt] = 20.5;
  else if( version==1 )
    txtX[ntxt] = 18.5;
  txtY[ntxt] = ymin/2;
  txtAlign[ntxt] = 21;
  txtFont[ntxt] = 42;
  ntxt++;

 
  float xw_ = 800;
  float yw_ = xw_/aspR;
 
  // the canvas
  TCanvas* c_=new TCanvas("Sigma","sigma",300,300,xw_,yw_);
  c_->SetLeftMargin( 110./xw_ );
  c_->SetRightMargin( 42./xw_ );
  c_->SetTopMargin(  40./yw_ );
  c_->SetBottomMargin( 55./yw_ ); 
  c_->SetFillColor(0);
  c_->SetTickx(1);
  c_->SetTicky(1);
  c_->SetFrameFillStyle(0);
  c_->SetFrameLineWidth(2);
  c_->SetFrameBorderMode(0);

  TH1F* h_= new TH1F( "bidon", "bidon", nBin_, 0, nBin_ );
  TAxis* ax_ = h_->GetXaxis();
  TAxis* ay_ = h_->GetYaxis();
  
  ax_->SetTitle("");
  ndivx = 0;
  ax_->SetNdivisions(ndivx);
  ax_->SetTitleOffset(titleOffsetX);
  ax_->SetLabelOffset(labelOffsetX);
  ax_->SetLabelSize(labelSizeX);

  ay_->SetTitle("Production Cross Section,   #sigma_{tot}    [pb]");
  ay_->SetNdivisions(ndivy);
  ay_->SetTitleOffset(titleOffsetY);
  ay_->SetTitleSize(titleSizeY);
  ay_->SetLabelOffset(labelOffsetY);
  ay_->SetLabelSize(labelSizeY);
  
  // now plotting
  c_->Draw();
  c_->cd();

  c_->SetLogy(true);
  h_->GetYaxis()->SetRangeUser(ymin,ymax);
  h_->Draw("hist][");
  

  for( size_t ii=0; ii<channel_.size(); ii++ )
    {
      size_t iChan = channel_[ii];
      float xx_ = xpos_[ii];
      float dxx_ = dx_[ii];
      type = 7;
      if  (chanName[iChan]  == "W8") type = 8;
      if  (chanName[iChan]  == "Z8") type = 8;
      if  (chanName[iChan]  == "WW8") type = 8;
      if  (chanName[iChan]  == "ZZ8") type = 8;
      DataPoint p_( chanSigma[iChan], chanEStat[iChan], chanETot[iChan], 
		    chanTheo[iChan], chanETheo[iChan],
		    xx_, dxx_ , type) ;
      p_.draw();
  
    }
  float yy_ = chanSigma[k_W]/4;
  float xx_ = nBin_-11;
  float dxx_ = 1.2;
  DataPoint p_( 0, 0, 0.3*yy_, 
		yy_, 0,
		xx_, dxx_, type ) ;
  p_.draw();
  
  for( size_t ii=0; ii<vline_.size(); ii++ )
    {
      draw_bin_grid( vline_[ii], vline_[ii], vmin_[ii]*ymin, ymax/vmax_[ii],
		     kGray+2, vstyle_[ii] );
    }

  c_->RedrawAxis();
  c_->GetFrame()->Draw();

  text_write();    

  return c_;
}

void draw_bin_grid( float xmin, float xmax, float ymin, float ymax, int iCol, int iStyle )
{
  TLine grid_;
  grid_.SetLineColor(iCol);
  grid_.SetLineStyle(iStyle);
  grid_.DrawLine(xmin,ymin,xmax,ymax);
}

void text_reset()
{
  for( size_t ii=0; ii<100; ii++ )
    {
      txt[ii]="";
      txtX[ii]=0.50;
      txtY[ii]=0.50;
      txtSize[ii]=0.050;
      txtAlign[ii]=11;
      txtFont[ii]=42;
      txtColor[ii]=kBlack;
      txtNDC[ii]=false;
    }
}

void text_init()
{
  text_reset();

  ntxt = 1;

  txt[0] = "CMS";
  txtSize[0] = 0.055;
  txtX[0] = 0.95;
  txtY[0] = 0.95;
  txtAlign[0] = 31;
  txtNDC[0]=true;
  txtFont[0] = 42;
  
}

void
text_write()
{  
  for( size_t ii=0; ii<ntxt; ii++ )
    { 
      TLatex latex;
      if( txtNDC[ii] ) latex.SetNDC();    
      latex.SetTextFont(txtFont[ii]);
      latex.SetTextSize(txtSize[ii]);    
      latex.SetTextColor(txtColor[ii]);    
      latex.SetTextAlign(txtAlign[ii]); 
      latex.DrawLatex(txtX[ii],txtY[ii],txt[ii].c_str());
    }
}

